@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013,2014 Ivan Alonso (Kaian)
- ** Copyright (C) 2013,2014 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  ** Copyright (C) 2012 Homer Project (http://www.sipcapture.org)
  **
  ** This program is free software: you can redistribute it and/or modify
@@ -141,7 +141,7 @@ capture_eep_init()
 void *
 accept_eep_client(void *data)
 {
-    capture_packet_t *pkt;
+    packet_t *pkt;
 
     // Begin accepting connections
     while (eep_cfg.server_sock > 0) {
@@ -150,7 +150,7 @@ accept_eep_client(void *data)
             // Avoid parsing while screen in being redrawn
             capture_lock();
             if (capture_packet_parse(pkt) != 0) {
-                capture_packet_destroy(pkt);
+                packet_destroy(pkt);
             }
             capture_unlock();
         }
@@ -175,10 +175,10 @@ capture_eep_deinit()
 }
 
 int
-capture_eep_send(capture_packet_t *pkt)
+capture_eep_send(packet_t *pkt)
 {
     // Dont send RTP packets
-    if (pkt->type == CAPTURE_PACKET_RTP)
+    if (pkt->type == PACKET_RTP)
         return 1;
 
     // Check we have a connection established
@@ -195,26 +195,26 @@ capture_eep_send(capture_packet_t *pkt)
 }
 
 int
-capture_eep_send_v2(capture_packet_t *pkt)
+capture_eep_send_v2(packet_t *pkt)
 {
     void* buffer;
-    unsigned int buflen = 0, tlen = 0;
+    uint32_t buflen = 0, tlen = 0;
     struct hep_hdr hdr;
     struct hep_timehdr hep_time;
     struct hep_iphdr hep_ipheader;
 #ifdef USE_IPV6
     struct hep_ip6hdr hep_ip6header;
 #endif
-    unsigned char *data = capture_packet_get_payload(pkt);
-    unsigned int len = capture_packet_get_payload_len(pkt);
-    capture_frame_t *frame = vector_first(pkt->frames);
+    unsigned char *data = packet_payload(pkt);
+    uint32_t len = packet_payloadlen(pkt);
+    frame_t *frame = vector_first(pkt->frames);
 
     /* Version && proto */
     hdr.hp_v = 2;
     hdr.hp_f = pkt->ip_version == 4 ? AF_INET : AF_INET6;
     hdr.hp_p = pkt->proto;
-    hdr.hp_sport = htons(pkt->sport);
-    hdr.hp_dport = htons(pkt->dport);
+    hdr.hp_sport = htons(pkt->src.port);
+    hdr.hp_dport = htons(pkt->dst.port);
 
     /* Timestamp */
     hep_time.tv_sec = frame->header->ts.tv_sec;
@@ -226,8 +226,8 @@ capture_eep_send_v2(capture_packet_t *pkt)
 
     /* IPv4 */
     if (pkt->ip_version == 4) {
-        inet_pton(AF_INET, pkt->ip_src, &hep_ipheader.hp_src);
-        inet_pton(AF_INET, pkt->ip_dst, &hep_ipheader.hp_dst);
+        inet_pton(AF_INET, pkt->src.ip, &hep_ipheader.hp_src);
+        inet_pton(AF_INET, pkt->dst.ip, &hep_ipheader.hp_dst);
         tlen += sizeof(struct hep_iphdr);
         hdr.hp_l += sizeof(struct hep_iphdr);
     }
@@ -235,8 +235,8 @@ capture_eep_send_v2(capture_packet_t *pkt)
 #ifdef USE_IPV6
     /* IPv6 */
     else if(pkt->ip_version == 6) {
-        inet_pton(AF_INET6, pkt->ip_src, &hep_ip6header.hp6_src);
-        inet_pton(AF_INET6, pkt->ip_dst, &hep_ip6header.hp6_dst);
+        inet_pton(AF_INET6, pkt->src.ip, &hep_ip6header.hp6_src);
+        inet_pton(AF_INET6, pkt->dst.ip, &hep_ip6header.hp6_dst);
         tlen += sizeof(struct hep_ip6hdr);
         hdr.hp_l += sizeof(struct hep_ip6hdr);
     }
@@ -286,20 +286,20 @@ capture_eep_send_v2(capture_packet_t *pkt)
 }
 
 int
-capture_eep_send_v3(capture_packet_t *pkt)
+capture_eep_send_v3(packet_t *pkt)
 {
     struct hep_generic *hg = NULL;
     void* buffer;
-    unsigned int buflen = 0, iplen = 0, tlen = 0;
+    uint32_t buflen = 0, iplen = 0, tlen = 0;
     hep_chunk_ip4_t src_ip4, dst_ip4;
 #ifdef USE_IPV6
     hep_chunk_ip6_t src_ip6, dst_ip6;
 #endif
     hep_chunk_t payload_chunk;
     hep_chunk_t authkey_chunk;
-    capture_frame_t *frame = vector_first(pkt->frames);
-    unsigned char *data = capture_packet_get_payload(pkt);
-    unsigned int len = capture_packet_get_payload_len(pkt);
+    frame_t *frame = vector_first(pkt->frames);
+    unsigned char *data = packet_payload(pkt);
+    uint32_t len = packet_payloadlen(pkt);
 
     hg = sng_malloc(sizeof(struct hep_generic));
 
@@ -323,13 +323,13 @@ capture_eep_send_v3(capture_packet_t *pkt)
         /* SRC IP */
         src_ip4.chunk.vendor_id = htons(0x0000);
         src_ip4.chunk.type_id = htons(0x0003);
-        inet_pton(AF_INET, pkt->ip_src, &src_ip4.data);
+        inet_pton(AF_INET, pkt->src.ip, &src_ip4.data);
         src_ip4.chunk.length = htons(sizeof(src_ip4));
 
         /* DST IP */
         dst_ip4.chunk.vendor_id = htons(0x0000);
         dst_ip4.chunk.type_id = htons(0x0004);
-        inet_pton(AF_INET, pkt->ip_dst, &dst_ip4.data);
+        inet_pton(AF_INET, pkt->dst.ip, &dst_ip4.data);
         dst_ip4.chunk.length = htons(sizeof(dst_ip4));
 
         iplen = sizeof(dst_ip4) + sizeof(src_ip4);
@@ -341,14 +341,14 @@ capture_eep_send_v3(capture_packet_t *pkt)
         /* SRC IPv6 */
         src_ip6.chunk.vendor_id = htons(0x0000);
         src_ip6.chunk.type_id = htons(0x0005);
-        inet_pton(AF_INET6, pkt->ip_src, &src_ip6.data);
-        src_ip6.chunk.length = htonl(sizeof(src_ip6));
+        inet_pton(AF_INET6, pkt->src.ip, &src_ip6.data);
+        src_ip6.chunk.length = htons(sizeof(src_ip6));
 
         /* DST IPv6 */
         dst_ip6.chunk.vendor_id = htons(0x0000);
         dst_ip6.chunk.type_id = htons(0x0006);
-        inet_pton(AF_INET6, pkt->ip_dst, &dst_ip6.data);
-        dst_ip6.chunk.length = htonl(sizeof(dst_ip6));
+        inet_pton(AF_INET6, pkt->dst.ip, &dst_ip6.data);
+        dst_ip6.chunk.length = htons(sizeof(dst_ip6));
 
         iplen = sizeof(dst_ip6) + sizeof(src_ip6);
     }
@@ -357,13 +357,13 @@ capture_eep_send_v3(capture_packet_t *pkt)
     /* SRC PORT */
     hg->src_port.chunk.vendor_id = htons(0x0000);
     hg->src_port.chunk.type_id = htons(0x0007);
-    hg->src_port.data = htons(pkt->sport);
+    hg->src_port.data = htons(pkt->src.port);
     hg->src_port.chunk.length = htons(sizeof(hg->src_port));
 
     /* DST PORT */
     hg->dst_port.chunk.vendor_id = htons(0x0000);
     hg->dst_port.chunk.type_id = htons(0x0008);
-    hg->dst_port.data = htons(pkt->dport);
+    hg->dst_port.data = htons(pkt->dst.port);
     hg->dst_port.chunk.length = htons(sizeof(hg->dst_port));
 
     /* TIMESTAMP SEC */
@@ -469,7 +469,7 @@ capture_eep_send_v3(capture_packet_t *pkt)
     return 0;
 }
 
-capture_packet_t *
+packet_t *
 capture_eep_receive()
 {
     switch (eep_cfg.capt_srv_version) {
@@ -481,21 +481,21 @@ capture_eep_receive()
     return NULL;
 }
 
-capture_packet_t *
+packet_t *
 capture_eep_receive_v2()
 {
     uint8_t family, proto;
     unsigned char *payload = 0;
-    unsigned int pos;
+    uint32_t pos;
     char buffer[MAX_CAPTURE_LEN] ;
-    //! Source and Destination Address
-    char ip_src[ADDRESSLEN], ip_dst[ADDRESSLEN];
-    //! Source and Destination Port
-    u_short sport, dport;
+    //! Source Address
+    address_t src;
+    //! Destination address
+    address_t dst;
     //! Packet header
     struct pcap_pkthdr header;
     //! New created packet pointer
-    capture_packet_t *pkt;
+    packet_t *pkt;
     //! EEP client data
     struct sockaddr eep_client;
     socklen_t eep_client_len;
@@ -530,23 +530,23 @@ capture_eep_receive_v2()
     /* IPv4 */
     if (family == AF_INET) {
         memcpy(&hep_ipheader, (void*) buffer + pos, sizeof(struct hep_iphdr));
-        inet_ntop(AF_INET, &hep_ipheader.hp_src, ip_src, sizeof(ip_src));
-        inet_ntop(AF_INET, &hep_ipheader.hp_dst, ip_dst, sizeof(ip_dst));
+        inet_ntop(AF_INET, &hep_ipheader.hp_src, src.ip, sizeof(src.ip));
+        inet_ntop(AF_INET, &hep_ipheader.hp_dst, dst.ip, sizeof(dst.ip));
         pos += sizeof(struct hep_iphdr);
     }
 #ifdef USE_IPV6
     /* IPv6 */
     else if(family == AF_INET6) {
         memcpy(&hep_ip6header, (void*) buffer + pos, sizeof(struct hep_ip6hdr));
-        inet_ntop(AF_INET6, &hep_ip6header.hp6_src, ip_src, sizeof(ip_src));
-        inet_ntop(AF_INET6, &hep_ip6header.hp6_dst, ip_dst, sizeof(ip_dst));
+        inet_ntop(AF_INET6, &hep_ip6header.hp6_src, src.ip, sizeof(src.ip));
+        inet_ntop(AF_INET6, &hep_ip6header.hp6_dst, dst.ip, sizeof(dst.ip));
         pos += sizeof(struct hep_ip6hdr);
     }
 #endif
 
     /* PORTS */
-    sport = ntohs(hdr.hp_sport);
-    dport = ntohs(hdr.hp_dport);
+    src.port = ntohs(hdr.hp_sport);
+    dst.port = ntohs(hdr.hp_dport);
 
     /* TIMESTAMP*/
     memcpy(&hep_time, (void*) buffer + pos, sizeof(struct hep_timehdr));
@@ -565,10 +565,11 @@ capture_eep_receive_v2()
     memcpy(payload, (void*) buffer + pos, header.caplen);
 
     // Create a new packet
-    pkt = capture_packet_create((family == AF_INET) ? 4 : 6, proto, ip_src, ip_dst, 0);
-    capture_packet_add_frame(pkt, &header, payload);
-    capture_packet_set_transport_data(pkt, sport, dport, CAPTURE_PACKET_SIP_UDP);
-    capture_packet_set_payload(pkt, payload, header.caplen);
+    pkt = packet_create((family == AF_INET) ? 4 : 6, proto, src, dst, 0);
+    packet_add_frame(pkt, &header, payload);
+    packet_set_transport_data(pkt, src.port, dst.port);
+    packet_set_type(pkt, PACKET_SIP_UDP);
+    packet_set_payload(pkt, payload, header.caplen);
 
     /* FREE */
     sng_free(payload);
@@ -576,7 +577,7 @@ capture_eep_receive_v2()
 
 }
 
-capture_packet_t *
+packet_t *
 capture_eep_receive_v3()
 {
 
@@ -591,20 +592,17 @@ capture_eep_receive_v3()
     char password[100];
     int password_len;
     unsigned char *payload = 0;
-    unsigned int len, pos;
+    uint32_t len, pos;
     char buffer[MAX_CAPTURE_LEN] ;
     //! Source and Destination Address
-    char ip_src[ADDRESSLEN], ip_dst[ADDRESSLEN];
+    address_t src, dst;
     //! EEP client data
     struct sockaddr eep_client;
     socklen_t eep_client_len;
-
-    //! Source and Destination Port
-    u_short sport, dport;
     //! Packet header
     struct pcap_pkthdr header;
     //! New created packet pointer
-    capture_packet_t *pkt;
+    packet_t *pkt;
 
     /* Receive EEP generic header */
     if (recvfrom(eep_cfg.server_sock, buffer, MAX_CAPTURE_LEN, 0, &eep_client, &eep_client_len) == -1)
@@ -629,12 +627,12 @@ capture_eep_receive_v3()
     if (family == AF_INET) {
         /* SRC IP */
         memcpy(&src_ip4, (void*) buffer + pos, sizeof(struct hep_chunk_ip4));
-        inet_ntop(AF_INET, &src_ip4.data, ip_src, sizeof(ip_src));
+        inet_ntop(AF_INET, &src_ip4.data, src.ip, sizeof(src.ip));
         pos += sizeof(struct hep_chunk_ip4);
 
         /* DST IP */
         memcpy(&dst_ip4, (void*) buffer + pos, sizeof(struct hep_chunk_ip4));
-        inet_ntop(AF_INET, &dst_ip4.data, ip_dst, sizeof(ip_dst));
+        inet_ntop(AF_INET, &dst_ip4.data, dst.ip, sizeof(src.ip));
         pos += sizeof(struct hep_chunk_ip4);
     }
 #ifdef USE_IPV6
@@ -642,20 +640,20 @@ capture_eep_receive_v3()
     else if(family == AF_INET6) {
         /* SRC IPv6 */
         memcpy(&src_ip6, (void*) buffer + pos, sizeof(struct hep_chunk_ip6));
-        inet_ntop(AF_INET6, &src_ip6.data, ip_src, sizeof(ip_src));
+        inet_ntop(AF_INET6, &src_ip6.data, src.ip, sizeof(src.ip));
         pos += sizeof(struct hep_chunk_ip6);
 
         /* DST IP */
         memcpy(&src_ip6, (void*) buffer + pos, sizeof(struct hep_chunk_ip6));
-        inet_ntop(AF_INET6, &dst_ip6.data, ip_dst, sizeof(ip_dst));
+        inet_ntop(AF_INET6, &dst_ip6.data, dst.ip, sizeof(dst.ip));
         pos += sizeof(struct hep_chunk_ip6);
     }
 #endif
 
     /* SRC PORT */
-    sport = ntohs(hg.src_port.data);
+    src.port = ntohs(hg.src_port.data);
     /* DST PORT */
-    dport = ntohs(hg.dst_port.data);
+    dst.port = ntohs(hg.dst_port.data);
     /* TIMESTAMP*/
     header.ts.tv_sec = ntohl(hg.time_sec.data);
     header.ts.tv_usec = ntohl(hg.time_usec.data);
@@ -688,10 +686,10 @@ capture_eep_receive_v3()
     memcpy(payload, (void*) buffer + pos, header.caplen);
 
     // Create a new packet
-    pkt = capture_packet_create((family == AF_INET)?4:6, proto, ip_src, ip_dst, 0);
-    capture_packet_add_frame(pkt, &header, payload);
-    capture_packet_set_transport_data(pkt, sport, dport, CAPTURE_PACKET_SIP_UDP);
-    capture_packet_set_payload(pkt, payload, header.caplen);
+    pkt = packet_create((family == AF_INET)?4:6, proto, src, dst, 0);
+    packet_add_frame(pkt, &header, payload);
+    packet_set_type(pkt, PACKET_SIP_UDP);
+    packet_set_payload(pkt, payload, header.caplen);
 
     /* FREE */
     sng_free(payload);
