@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013,2014 Ivan Alonso (Kaian)
- ** Copyright (C) 2013,2014 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -44,15 +44,47 @@ struct CipherSuite TLS_RSA_WITH_AES_128_CBC_SHA =
 struct CipherSuite TLS_RSA_WITH_AES_256_CBC_SHA =
 { 0x00, 0x35 };
 
+#define TLS_DEBUG 0
+
+void
+tls_debug_print_hex (char *desc, const void *ptr, int len) {
+#if TLS_DEBUG == 1
+    int i;
+    uint8_t buff[17];
+    uint8_t *data = (uint8_t*)ptr;
+
+    printf ("%s [%d]:\n", desc, len);
+    if (len == 0) return;
+    for (i = 0; i < len; i++) {
+        if ((i % 16) == 0) {
+            if (i != 0)
+                printf (" |%s|\n", buff);
+            printf ("|");
+        }
+        printf (" %02x", data[i]);
+        if ((data[i] < 0x20) || (data[i] > 0x7e))
+            buff[i % 16] = '.';
+        else
+            buff[i % 16] = data[i];
+        buff[(i % 16) + 1] = '\0';
+    }
+    while ((i % 16) != 0) {
+        printf ("   ");
+        i++;
+    }
+    printf (" |%-16s|\n\n", buff);
+#endif
+}
+
 int
 P_hash(const char *digest, unsigned char *dest, int dlen, unsigned char *secret, int sslen,
        unsigned char *seed, int slen)
 {
-    unsigned char hmac[20];
-    unsigned int hlen;
+    unsigned char hmac[48];
+    uint32_t hlen;
     HMAC_CTX hm;
     const EVP_MD *md = EVP_get_digestbyname(digest);
-    unsigned int tmpslen;
+    uint32_t tmpslen;
     unsigned char tmpseed[slen];
     unsigned char *out = dest;
     int pending = dlen;
@@ -83,8 +115,8 @@ P_hash(const char *digest, unsigned char *dest, int dlen, unsigned char *secret,
 }
 
 int
-PRF(unsigned char *dest, int dlen, unsigned char *pre_master_secret, int plen, unsigned char *label,
-    unsigned char *seed, int slen)
+PRF(unsigned char *dest, int dlen, unsigned char *pre_master_secret,
+    int plen, unsigned char *label, unsigned char *seed, int slen)
 {
     int i;
 
@@ -104,6 +136,7 @@ PRF(unsigned char *dest, int dlen, unsigned char *pre_master_secret, int plen, u
     unsigned char fseed[slen + llen];
     memcpy(fseed, label, llen);
     memcpy(fseed + llen, seed, slen);
+    tls_debug_print_hex("hash seed",fseed, slen + llen);
 
     // Get enough MD5 and SHA1 data to fill output len
     P_hash("MD5", h_md5, dlen, pre_master_secret, hplen, fseed, slen + llen);
@@ -113,18 +146,36 @@ PRF(unsigned char *dest, int dlen, unsigned char *pre_master_secret, int plen, u
     for (i = 0; i < dlen; i++)
         dest[i] = h_md5[i] ^ h_sha[i];
 
+    tls_debug_print_hex("PRF out", dest, dlen);
+    return dlen;
+}
+
+int
+PRF12(unsigned char *dest, int dlen, unsigned char *pre_master_secret,
+        int plen, unsigned char *label, unsigned char *seed, int slen) {
+
+    // Concatenate given seed to the label to get the final seed
+    int llen = strlen((const char*) label);
+    unsigned char fseed[slen + llen];
+    memcpy(fseed, label, llen);
+    memcpy(fseed + llen, seed, slen);
+    tls_debug_print_hex("hash seed",fseed, slen + llen);
+
+    // Get enough SHA256 data to fill output len
+    P_hash("SHA256", dest, dlen, pre_master_secret, plen, fseed, slen + llen);
+    tls_debug_print_hex("PRF out", dest, dlen);
     return dlen;
 }
 
 struct SSLConnection *
-tls_connection_create(struct in_addr caddr, u_short cport, struct in_addr saddr, u_short sport) {
+tls_connection_create(struct in_addr caddr, uint16_t cport, struct in_addr saddr, uint16_t sport) {
     struct SSLConnection *conn = NULL;
     conn = sng_malloc(sizeof(struct SSLConnection));
 
     memcpy(&conn->client_addr, &caddr, sizeof(struct in_addr));
     memcpy(&conn->server_addr, &saddr, sizeof(struct in_addr));
-    memcpy(&conn->client_port, &cport, sizeof(u_short));
-    memcpy(&conn->server_port, &sport, sizeof(u_short));
+    memcpy(&conn->client_port, &cport, sizeof(uint16_t));
+    memcpy(&conn->server_port, &sport, sizeof(uint16_t));
 
     SSL_library_init();
     ERR_load_crypto_strings();
@@ -133,7 +184,7 @@ tls_connection_create(struct in_addr caddr, u_short cport, struct in_addr saddr,
     if (!(conn->ssl_ctx = SSL_CTX_new(SSLv23_server_method())))
         return NULL;
 
-    SSL_CTX_use_PrivateKey_file(conn->ssl_ctx, capture_get_keyfile(),
+    SSL_CTX_use_PrivateKey_file(conn->ssl_ctx, capture_keyfile(),
                                 SSL_FILETYPE_PEM);
     if (!(conn->ssl = SSL_new(conn->ssl_ctx)))
         return NULL;
@@ -186,13 +237,13 @@ tls_check_keyfile(const char *keyfile)
     ERR_load_crypto_strings();
     OpenSSL_add_all_algorithms();
 
-    if (access(capture_get_keyfile(), R_OK) != 0)
+    if (access(capture_keyfile(), R_OK) != 0)
         return 0;
 
     if (!(ssl_ctx = SSL_CTX_new(SSLv23_server_method())))
         return 0;
 
-    SSL_CTX_use_PrivateKey_file(ssl_ctx, capture_get_keyfile(), SSL_FILETYPE_PEM);
+    SSL_CTX_use_PrivateKey_file(ssl_ctx, capture_keyfile(), SSL_FILETYPE_PEM);
     if (!(ssl = SSL_new(ssl_ctx)))
         return 0;
 
@@ -203,7 +254,7 @@ tls_check_keyfile(const char *keyfile)
 }
 
 int
-tls_connection_dir(struct SSLConnection *conn, struct in_addr addr, u_short port)
+tls_connection_dir(struct SSLConnection *conn, struct in_addr addr, uint16_t port)
 {
     if (conn->client_addr.s_addr == addr.s_addr && conn->client_port == port)
         return 0;
@@ -213,7 +264,7 @@ tls_connection_dir(struct SSLConnection *conn, struct in_addr addr, u_short port
 }
 
 struct SSLConnection*
-tls_connection_find(struct in_addr addr, u_short port) {
+tls_connection_find(struct in_addr addr, uint16_t port) {
     struct SSLConnection *conn;
 
     for (conn = connections; conn; conn = conn->next) {
@@ -225,21 +276,21 @@ tls_connection_find(struct in_addr addr, u_short port) {
 }
 
 int
-tls_process_segment(capture_packet_t *packet, struct tcphdr *tcp)
+tls_process_segment(packet_t *packet, struct tcphdr *tcp)
 {
     struct SSLConnection *conn;
-    const u_char *payload = capture_packet_get_payload(packet);
-    uint32_t size_payload = capture_packet_get_payload_len(packet);
-    uint8 *out;
+    const u_char *payload = packet_payload(packet);
+    uint32_t size_payload = packet_payloadlen(packet);
+    uint8_t *out;
     uint32_t outl = packet->payload_len;
     out = sng_malloc(outl);
     struct in_addr ip_src, ip_dst;
-    u_short sport = packet->sport;
-    u_short dport = packet->dport;
+    uint16_t sport = packet->src.port;
+    uint16_t dport = packet->dst.port;
 
     // Convert addresses
-    inet_pton(AF_INET, packet->ip_src, &ip_src);
-    inet_pton(AF_INET, packet->ip_dst, &ip_dst);
+    inet_pton(AF_INET, packet->src.ip, &ip_src);
+    inet_pton(AF_INET, packet->dst.ip, &ip_dst);
 
     // Try to find a session for this ip
     if ((conn = tls_connection_find(ip_src, sport))) {
@@ -263,8 +314,8 @@ tls_process_segment(capture_packet_t *packet, struct tcphdr *tcp)
                 // Process data segment!
                 if (tls_process_record(conn, payload, size_payload, &out, &outl) == 0) {
                     if ((int32_t) outl > 0) {
-                        capture_packet_set_payload(packet, out, outl);
-                        capture_packet_set_type(packet, CAPTURE_PACKET_SIP_TLS);
+                        packet_set_payload(packet, out, outl);
+                        packet_set_type(packet, PACKET_SIP_TLS);
                         return 0;
                     }
                 }
@@ -287,8 +338,8 @@ tls_process_segment(capture_packet_t *packet, struct tcphdr *tcp)
 }
 
 int
-tls_process_record(struct SSLConnection *conn, const uint8 *payload, const int len, uint8 **out,
-                   uint32_t *outl)
+tls_process_record(struct SSLConnection *conn, const uint8_t *payload,
+                   const int len, uint8_t **out, uint32_t *outl)
 {
     struct TLSPlaintext *record;
     int record_len;
@@ -310,7 +361,7 @@ tls_process_record(struct SSLConnection *conn, const uint8 *payload, const int l
         switch (record->type) {
             case handshake:
                 // Hanshake Record, Try to get MasterSecret data
-                if (tls_process_record_handshake(conn, fragment) != 0)
+                if (tls_process_record_handshake(conn, fragment, UINT16_INT(record->length)) != 0)
                     return 1;
                 break;
             case change_cipher_spec:
@@ -329,14 +380,16 @@ tls_process_record(struct SSLConnection *conn, const uint8 *payload, const int l
     }
 
     // MultiRecord packet
-    if (len > record_len)
+    if (len > record_len) {
+        *outl = len;
         return tls_process_record(conn, payload + record_len, len - record_len, out, outl);
+    }
 
     return 0;
 }
 
 int
-tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment)
+tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment, const int len)
 {
     struct Handshake *handshake;
     struct ClientHello *clienthello;
@@ -360,11 +413,21 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment)
                 memcpy(&conn->client_random, &clienthello->random, sizeof(struct Random));
 
                 // Check we have a TLS handshake
-                if (!(clienthello->client_version.major == 0x03
-                      && clienthello->client_version.minor == 0x01)) {
+                if (!(clienthello->client_version.major == 0x03)) {
                     tls_connection_destroy(conn);
                     return 1;
                 }
+
+                // Only TLS 1.0, 1.1 or 1.2 connections
+                if (clienthello->client_version.minor != 0x01
+                        && clienthello->client_version.minor != 0x02
+                        && clienthello->client_version.minor != 0x03) {
+                    tls_connection_destroy(conn);
+                    return 1;
+                }
+
+                // Store TLS version
+                conn->version = clienthello->client_version.minor;
                 break;
             case server_hello:
                 // Store server random
@@ -373,7 +436,7 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment)
                 // Get the selected cipher
                 memcpy(&conn->cipher_suite,
                        body + sizeof(struct ServerHello) + serverhello->session_id_length,
-                       sizeof(uint16));
+                       sizeof(uint16_t));
                 // Check if we have a handled cipher
                 if (tls_connection_load_cipher(conn) != 0) {
                     tls_connection_destroy(conn);
@@ -394,22 +457,45 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment)
                                     (unsigned char *) &conn->pre_master_secret,
                                     conn->server_private_key->pkey.rsa, RSA_PKCS1_PADDING);
 
-                unsigned char *seed = sng_malloc(sizeof(struct Random) * 2);
+                tls_debug_print_hex("client_random", &conn->client_random, 32);
+                tls_debug_print_hex("server_random", &conn->server_random, 32);
+
+                uint8_t *seed = sng_malloc(sizeof(struct Random) * 2);
                 memcpy(seed, &conn->client_random, sizeof(struct Random));
                 memcpy(seed + sizeof(struct Random), &conn->server_random, sizeof(struct Random));
 
-                // Get MasterSecret
-                PRF((unsigned char *) &conn->master_secret, sizeof(struct MasterSecret),
-                    (unsigned char *) &conn->pre_master_secret, sizeof(struct PreMasterSecret),
-                    (unsigned char *) "master secret", seed, sizeof(struct Random) * 2);
+                if (conn->version < 3) {
+                    // Get MasterSecret
+                    PRF((unsigned char *) &conn->master_secret, sizeof(struct MasterSecret),
+                        (unsigned char *) &conn->pre_master_secret, sizeof(struct PreMasterSecret),
+                        (unsigned char *) "master secret", seed, sizeof(struct Random) * 2);
+                } else {
+                    PRF12((unsigned char *) &conn->master_secret, sizeof(struct MasterSecret),
+                          (unsigned char *) &conn->pre_master_secret, sizeof(struct PreMasterSecret),
+                          (unsigned char *) "master secret", seed, sizeof(struct Random) * 2);
+                }
+                tls_debug_print_hex("master_secret", conn->master_secret.random, 48);
 
-                memcpy(seed, &conn->server_random, sizeof(struct Random));
+                memcpy(seed, &conn->server_random, sizeof(struct Random) * 2);
                 memcpy(seed + sizeof(struct Random), &conn->client_random, sizeof(struct Random));
 
                 // Generate MACs, Write Keys and IVs
-                PRF((unsigned char *) &conn->key_material, sizeof(struct tls_data),
-                    (unsigned char *) &conn->master_secret, sizeof(struct MasterSecret),
-                    (unsigned char *) "key expansion", seed, sizeof(struct Random) * 2);
+                if (conn->version < 3) {
+                    PRF((unsigned char *) &conn->key_material, sizeof(struct tls_data),
+                        (unsigned char *) &conn->master_secret, sizeof(struct MasterSecret),
+                        (unsigned char *) "key expansion", seed, sizeof(struct Random) * 2);
+                } else {
+                    PRF12((unsigned char *) &conn->key_material, sizeof(struct tls_data),
+                          (unsigned char *) &conn->master_secret, sizeof(struct MasterSecret),
+                          (unsigned char *) "key expansion", seed, sizeof(struct Random) * 2);
+                }
+
+                tls_debug_print_hex("client_write_MAC_key", conn->key_material.client_write_MAC_key, 20);
+                tls_debug_print_hex("server_write_MAC_key", conn->key_material.server_write_MAC_key, 20);
+                tls_debug_print_hex("client_write_key",     conn->key_material.client_write_key, 32);
+                tls_debug_print_hex("server_write_key",     conn->key_material.server_write_key, 32);
+                tls_debug_print_hex("client_write_IV",      conn->key_material.client_write_IV, 16);
+                tls_debug_print_hex("server_write_IV",      conn->key_material.server_write_IV, 16);
 
                 // Done with the seed
                 sng_free(seed);
@@ -426,14 +512,15 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment)
                                0);
 
                 break;
+            case new_session_ticket:
             case finished:
                 break;
             default:
                 if (conn->encrypted) {
                     // Encrypted Hanshake Message
-                    unsigned char *decoded = sng_malloc(48);
-                    uint32_t decodedlen;
-                    tls_process_record_data(conn, fragment, 48, &decoded, &decodedlen);
+                    uint8_t *decoded = sng_malloc(len);
+                    uint32_t decodedlen = len;
+                    tls_process_record_data(conn, fragment, len, &decoded, &decodedlen);
                     sng_free(decoded);
                 }
                 break;
@@ -444,13 +531,14 @@ tls_process_record_handshake(struct SSLConnection *conn, const opaque *fragment)
 }
 
 int
-tls_process_record_data(struct SSLConnection *conn, const opaque *fragment, const int len,
-                        uint8 **out, uint32_t *outl)
+tls_process_record_data(struct SSLConnection *conn, const opaque *fragment,
+                        const int len, uint8_t **out, uint32_t *outl)
 {
     EVP_CIPHER_CTX *evp;
-    unsigned char pad;
-    unsigned char *decoded;
-    uint32_t dlen;
+    uint8_t pad;
+    size_t flen = len;
+
+    tls_debug_print_hex("Ciphertext", fragment, len);
 
     if (conn->direction == 0) {
         evp = &conn->client_cipher_ctx;
@@ -458,16 +546,34 @@ tls_process_record_data(struct SSLConnection *conn, const opaque *fragment, cons
         evp = &conn->server_cipher_ctx;
     }
 
-    decoded = sng_malloc(len);
-    EVP_Cipher(evp, decoded, (unsigned char *) fragment, len);
+    // TLS 1.1 and later extract explicit IV
+    if (conn->version >= 2 && len > 16) {
+        if (conn->direction == 0) {
+            EVP_CipherInit(evp, conn->ciph,
+                           conn->key_material.client_write_key,
+                           fragment, 0);
+        } else {
+            EVP_CipherInit(evp, conn->ciph,
+                           conn->key_material.server_write_key,
+                           fragment, 0);
+        }
+        flen -= 16;
+        fragment += 16;
+    }
+
+    size_t dlen = len;
+    uint8_t *decoded = sng_malloc(dlen);
+    EVP_Cipher(evp, decoded, (unsigned char *) fragment, flen);
+    tls_debug_print_hex("Plaintext", decoded, flen);
 
     // Get padding counter and remove from data
-    pad = decoded[len - 1];
-    dlen = (len - (pad + 1) - /* Trailing MAC */20);
+    pad = decoded[flen - 1];
+    dlen = flen - (pad + 1);
+    tls_debug_print_hex("Mac", decoded + (dlen - 20), 20);
 
     if ((int32_t)dlen > 0 && dlen <= *outl) {
         memcpy(*out, decoded, dlen);
-        *outl = dlen;
+        *outl = dlen - 20 /* Trailing MAC */;
     }
 
     // Clenaup decoded memory
@@ -488,5 +594,6 @@ tls_connection_load_cipher(struct SSLConnection *conn)
     } else {
         return 1;
     }
+
     return 0;
 }
