@@ -170,6 +170,11 @@ call_list_resize(ui_t *ui)
 
     // Change the main window size
     wresize(ui->win, maxy, maxx);
+
+    // Store new size
+    ui->width = maxx;
+    ui->height = maxy;
+
     // Calculate available printable area
     wresize(info->list_win, maxy - 5, maxx - 4);
     // Force list redraw
@@ -294,7 +299,7 @@ call_list_draw_list(ui_t *ui)
     int listh, listw, cline = 0;
     struct sip_call *call = NULL;
     int i, collen;
-    char coltext[256];
+    char coltext[SIP_ATTR_MAXLEN];
     int colid;
     int colpos;
     int color;
@@ -466,8 +471,8 @@ const char *
 call_list_line_text(ui_t *ui, sip_call_t *call, char *text)
 {
     int i, collen;
-    char call_attr[256];
-    char coltext[256];
+    char call_attr[SIP_ATTR_MAXLEN];
+    char coltext[SIP_ATTR_MAXLEN];
     int colid;
 
     // Get panel info
