@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013,2014 Ivan Alonso (Kaian)
- ** Copyright (C) 2013,2014 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -48,6 +48,30 @@ call_group_destroy(sip_call_group_t *group)
     sng_free(group);
 }
 
+bool
+call_group_has_changed(sip_call_group_t *group)
+{
+    bool changed = false;
+
+    // Check if any of the group has changed
+    // We check all the calls even after we found a changed one to reset all
+    // the changed pointers
+    sip_call_t *call = NULL;
+    while ((call = call_group_get_next(group, call))) {
+        if (call_has_changed(call)) {
+            changed = true;
+
+            // If this group is based on a Call-Id, check there are no new call related
+            if (group->callid && !strcmp(group->callid, call->callid)) {
+                call_group_add_calls(group, call->xcalls);
+            }
+        }
+    }
+
+    // Return if any of the calls have changed
+    return changed;
+}
+
 sip_call_group_t *
 call_group_clone(sip_call_group_t *original)
 {
@@ -67,7 +91,23 @@ call_group_clone(sip_call_group_t *original)
 void
 call_group_add(sip_call_group_t *group, sip_call_t *call)
 {
-    vector_append(group->calls, call);
+    if (!call_group_exists(group, call)) {
+        vector_append(group->calls, call);
+    }
+}
+
+void
+call_group_add_calls(sip_call_group_t *group, vector_t *calls)
+{
+    sip_call_t *call;
+    vector_iter_t it = vector_iterator(calls);
+
+    // Get the call with the next chronological message
+    while ((call = vector_iterator_next(&it))) {
+        if (!call_group_exists(group, call)) {
+            vector_append(group->calls, call);
+        }
+    }
 }
 
 void
@@ -232,6 +272,8 @@ call_group_get_next_stream(sip_call_group_t *group, rtp_stream_t *stream)
         while ( (cand = vector_iterator_next(&streams))) {
             if (!stream_get_count(cand))
                 continue;
+            if (cand->type != PACKET_RTP)
+                continue;
 
             // candidate must be between msg and next
             if (stream_is_older(cand, stream) && (!next || stream_is_older(next, cand))) {
