@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013,2014 Ivan Alonso (Kaian)
- ** Copyright (C) 2013,2014 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -48,6 +48,8 @@ typedef struct sip_call_group sip_call_group_t;
  * a calls group flow.
  */
 struct sip_call_group {
+    //! For extended display, main call-id
+    char *callid;
     //! Calls array in the group
     vector_t *calls;
     //! Color of the last printed call in mode Color-by-Call
@@ -74,6 +76,18 @@ call_group_create();
 void
 call_group_destroy(sip_call_group_t *group);
 
+/**
+ * @brief Check if any of the calls of the group has changed
+ *
+ * This checks all the group flags to check if any of the call has
+ * changed.
+ *
+ * @param ggroup Call group structure pointer
+ * @return true if any of the calls of the group has changed, false otherwise
+ */
+bool
+call_group_has_changed(sip_call_group_t *group);
+
 /**
  * @brief Clone an existing call group
  *
@@ -94,6 +108,15 @@ call_group_clone(sip_call_group_t *original);
 void
 call_group_add(sip_call_group_t *group, sip_call_t *call);
 
+/**
+ * @brief Add several Calls to the group
+ *
+ * @param group Pointer to an existing group
+ * @param calls Pointer to a vector with calls
+ */
+void
+call_group_add_calls(sip_call_group_t *group, vector_t *calls);
+
 /**
  * @brief Remove a call from the group
  *
