@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2015 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2015 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -76,6 +76,7 @@ enum key_actions {
     ACTION_CLEAR_CALLS,
     ACTION_TOGGLE_SYNTAX,
     ACTION_CYCLE_COLOR,
+    ACTION_COMPRESS,
     ACTION_SHOW_HOSTNAMES,
     ACTION_SHOW_ALIAS,
     ACTION_TOGGLE_PAUSE,
@@ -90,6 +91,7 @@ enum key_actions {
     ACTION_SHOW_STATS,
     ACTION_COLUMN_MOVE_UP,
     ACTION_COLUMN_MOVE_DOWN,
+    ACTION_SDP_INFO,
     ACTION_DISP_FILTER,
     ACTION_SAVE,
     ACTION_SELECT,
@@ -100,10 +102,12 @@ enum key_actions {
     ACTION_DECREASE_RAW,
     ACTION_RESET_RAW,
     ACTION_ONLY_SDP,
-    ACTION_SDP_INFO,
-    ACTION_COMPRESS,
     ACTION_TOGGLE_HINT,
     ACTION_AUTOSCROLL,
+    ACTION_SORT_PREV,
+    ACTION_SORT_NEXT,
+    ACTION_SORT_SWAP,
+    ACTION_TOGGLE_TIME,
     ACTION_SENTINEL
 };
 
