@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2015 Ivan Alonso (Kaian)
- ** Copyright (C) 2015 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -56,7 +56,6 @@ typedef struct setting_option setting_t;
 #define SETTING_ENUM_SDP_INFO    (const char *[]){ "off", "first", "full", "compressed", NULL}
 #define SETTING_ENUM_STORAGE     (const char *[]){ "none", "memory", NULL }
 #define SETTING_ENUM_HEPVERSION  (const char *[]){ "2", "3", NULL }
-#define SETTING_ENUM_MEDIA       (const char *[]){ "on", "off", "rtcp", NULL }
 
 //! Other useful defines
 #define SETTING_ON  "on"
@@ -75,7 +74,6 @@ enum setting_id {
     SETTING_ALTKEY_HINT,
     SETTING_EXITPROMPT,
     SETTING_CAPTURE_LIMIT,
-    SETTING_CAPTURE_LOOKUP,
     SETTING_CAPTURE_DEVICE,
     SETTING_CAPTURE_OUTFILE,
     SETTING_CAPTURE_KEYFILE,
@@ -84,7 +82,6 @@ enum setting_id {
     SETTING_SIP_NOINCOMPLETE,
     SETTING_SIP_CALLS,
     SETTING_SAVEPATH,
-    SETTING_DISPLAY_HOST,
     SETTING_DISPLAY_ALIAS,
     SETTING_CL_SCROLLSTEP,
     SETTING_CL_COLORATTR,
