@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013,2014 Ivan Alonso (Kaian)
- ** Copyright (C) 2013,2014 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #include "option.h"
 #include "sip_attr.h"
 #include "util.h"
-#include "ui_manager.h"
+#include "curses/ui_manager.h"
 
 static sip_attr_hdr_t attrs[SIP_ATTR_COUNT] = {
     { SIP_ATTR_CALLINDEX,   "index",       "Idx",  "Call Index",    4 },
@@ -48,8 +48,6 @@ static sip_attr_hdr_t attrs[SIP_ATTR_COUNT] = {
     { SIP_ATTR_DATE,        "date",        NULL,   "Date",          10 },
     { SIP_ATTR_TIME,        "time",        NULL,   "Time",          8 },
     { SIP_ATTR_METHOD,      "method",      NULL,   "Method",        10, sip_attr_color_method },
-    { SIP_ATTR_SDP_ADDRESS, "sdpaddress",  NULL,   "SDP Address",   22 },
-    { SIP_ATTR_SDP_PORT,    "sdpport",     NULL,   "SDP Port",      5 },
     { SIP_ATTR_TRANSPORT,   "transport",   "Trans", "Transport",    3 },
     { SIP_ATTR_MSGCNT,      "msgcnt",      "Msgs", "Message Count", 5 },
     { SIP_ATTR_CALLSTATE,   "state",       NULL,   "Call State",    10, sip_attr_color_state },
