@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2015 Ivan Alonso (Kaian)
- ** Copyright (C) 2015 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 #include "config.h"
 #include <stdarg.h>
+#include <stdbool.h>
 #include "vector.h"
 #include "rtp.h"
 #include "sip_msg.h"
@@ -67,7 +68,12 @@ struct sip_call {
     signed char filtered;
     //! Call State. For dialogs starting with an INVITE method
     int state;
-
+    //! Changed flag. For interface optimal updates
+    bool changed;
+    //! List of calls with with this call as X-Call-Id
+    vector_t *xcalls;
+    //! Cseq from invite startint the call
+    uint32_t invitecseq;
     //! List of messages of this call (sip_msg_t*)
     vector_t *msgs;
     //! Message when conversation started and ended
@@ -110,6 +116,18 @@ call_destroy(sip_call_t *call);
 void
 call_destroyer(void *call);
 
+/**
+ * @brief Return if the call has changed
+ *
+ * Check if the call has changed since the last time * this function was
+ * invoked. We consider list has changed when a new message or stream
+ * has been added to the call.
+ *
+ * @return true if call has changed, false otherwise
+ */
+bool
+call_has_changed(sip_call_t *call);
+
 /**
  * @brief Append message to the call's message list
  *
@@ -140,7 +158,7 @@ call_add_stream(sip_call_t *call, rtp_stream_t *stream);
  * @param packet new RTP packet from call rtp streams
  */
 void
-call_add_rtp_packet(sip_call_t *call, capture_packet_t *packet);
+call_add_rtp_packet(sip_call_t *call, packet_t *packet);
 
 /**
  * @brief Getter for call messages linked list size
@@ -154,19 +172,6 @@ call_add_rtp_packet(sip_call_t *call, capture_packet_t *packet);
 int
 call_msg_count(sip_call_t *call);
 
-/**
- * @brief Finds the other leg of this call.
- *
- * If this call has a X-CID or X-Call-ID header, that call will be
- * find and returned. Otherwise, a call with X-CID or X-Call-ID header
- * matching the given call's Call-ID will be find or returned.
- *
- * @param call SIP call structure
- * @return The other call structure or NULL if none found
- */
-sip_call_t *
-call_get_xcall(sip_call_t *call);
-
 /**
  * @brief Determine if a dilog is a call in progress
  *
@@ -226,4 +231,26 @@ call_get_attribute(struct sip_call *call, enum sip_attr_id id, char *value);
 const char *
 call_state_to_str(int state);
 
+/**
+ * @brief Compare two calls based on a given attribute
+ *
+ * @return 0 if call attributes are equal
+ * @return 1 if first call is greater
+ * @return -1 if first call is lesser
+ */
+int
+call_attr_compare(sip_call_t *one, sip_call_t *two, enum sip_attr_id id);
+
+/**
+ * @brief Relate this two calls
+ *
+ * Add a call to the internal xcalls vector of another call.
+ * This calls are related by the SIP header X-Call-Id or X-CID
+ *
+ * @param call SIP call structure
+ * @param xcall SIP call structure
+ */
+void
+call_add_xcall(sip_call_t *call, sip_call_t *xcall);
+
 #endif /* __SNGREP_SIP_CALL_H */
