@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2015 Ivan Alonso (Kaian)
- ** Copyright (C) 2015 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -47,26 +47,30 @@
 #define TEST_PCAP_INPUT "aaa.pcap"
 #endif
 
+/* keys array needs to be of type "char" */
+const char keys[];
+
 int
 main()
 {
     int ppipe[2];
     int unused, ret = 0;
+    int child;
     unused = pipe(ppipe);
 
     // Max test duration
     alarm(TEST_MAX_DURATION);
 
-    if (!fork()) {
-        char *argv[] =
-                {
-                  "../src/sngrep",
-                  "-I",
-                  TEST_PCAP_INPUT,
-                  0 };
+    if ((child = fork()) < 0) {
+        fprintf(stderr, "Fatal: unable to fork test.\n");
+        return 127;
+    } else if (child == 0) {
+        // Child process, run sngrep with test pcap
         dup2(ppipe[0], STDIN_FILENO);
+        char *argv[] = { "../src/sngrep", "-I", TEST_PCAP_INPUT, 0 };
         execv(argv[0], argv);
     } else {
+        // Parent process, send keys to child stdin
         usleep(TEST_INITIAL_WAIT);
         int i;
         for (i = 0; keys[i]; i++) {
